pub struct PayloadDecoder;

Implementations

source

impl PayloadDecoder

source

pub fn decode_to_wallet_identifier( payload: &ByteBuf ) -> Result<WalletIdentifier>

Decode the payload to a wallet identifier The payload should be in the following format: {chain}|{network}|{pub_key} where chain, network and pub_key are hex encoded Used for the following transactions:

  • [TransactionType::WalletRegistration]
source

pub fn decode_to_deposit(payload: &ByteBuf) -> Result<Deposit>

Decode the payload to a deposit

source

pub fn decode_to_wallet_register_request( payload: &ByteBuf ) -> Result<WalletRegisterRequest>

Decode the payload to wallet register request The payload should be in the following format: {chain}|{network}|{pub_key}

source

pub fn decode_to_reset_main_secret_request( payload: &ByteBuf ) -> Result<ResetMainSecretRequest>

Decode the payload to reset main secret request The payload should be in the following format: {data.encrypted_pri_key}|{data.l2_pub_key}